@@ -171,9 +171,9 @@ extern ENGINE *tcn_ssl_engine;
     || (errnum == X509_V_ERR_CERT_UNTRUSTED) \
     || (errnum == X509_V_ERR_UNABLE_TO_VERIFY_LEAF_SIGNATURE))
 
-#define SSL_DEFAULT_PASS_PROMPT "Some of your private key files are encrypted for security reasons.\n"  \
-                                "In order to read them you have to provide the pass phrases.\n"         \
-                                "Enter password :"
+#define SSL_DEFAULT_PASS_PROMPT "Some of your private key files are encrypted for security reasons.\n" \
+                                "In order to read them you have to provide the pass phrases.\n"        \
+                                "Enter pass phrase:"
 
 #define SSL_CIPHERS_ALWAYS_DISABLED         ("!aNULL:!eNULL:!EXP:")
 
@@ -358,9 +358,9 @@ typedef struct {
                          */
     } reneg_state;
     enum {
-    	PHA_NONE = 0,	/* Before PHA */
-		PHA_STARTED,	/* PHA req sent to client but no response */
-		PHA_COMPLETE	/* Client has returned cert */
+        PHA_NONE = 0,   /* Before PHA */
+        PHA_STARTED,    /* PHA req sent to client but no response */
+        PHA_COMPLETE    /* Client has returned cert */
     } pha_state;
     apr_socket_t   *sock;
     apr_pollset_t  *pollset;
